import { fabric } from 'fabric';
import Handler from './Handler';
/**
 * 全局的事件处理器
 */
declare class EventHandler {
    /** @ignore */
    handler: Handler;
    /** @ignore */
    panning: boolean;
    clonedObject?: fabric.Object;
    /** @ignore */
    constructor(handler: Handler);
    /** @ignore */
    initialize(): void;
    /**
     * 画布元素修改事件的回调，需要在初始化的时候注册
     */
    private modified;
    /**
     * 鼠标点击事件的回调，需要在初始化的时候注册
     */
    private mouseDown;
    /**
     * 鼠标移动事件
     * @param opt event事件
     */
    private mouseMove;
    /**
     * 对象移动事件
     * @param opt
     * @returns
     */
    private moving;
    /**
     * 鼠标悬停时间
     */
    private mouseover;
    private roundRect;
    private mouseout;
    /**
     * 鼠标按键抬起事件
     */
    private mouseUp;
    /**
     * 元素缩放事件
     */
    private scaling;
    /**
     * afterRender事件
     */
    private afterRender;
    /**
     * beforeRender事件
     */
    private beforeRender;
    /**
     * 方向键移动
     * @param e 事件
     * @returns 无
     */
    arrowMoving(opt: KeyboardEvent): void;
    /**
     * 键盘按键事件
     */
    private keydown;
    /**
     * 复制画布元素
     * @param obj 需被复制的画布元素，不传入时默认画布中当前选择的元素
     * @param callback clone完成后的callback
     * @returns
     */
    copy(defaultPaste?: boolean): void;
    /**
     * 黏贴事件
     */
    paste(event: any): Promise<void>;
    /**
     * 复制2
     */
    copy2(): void;
    /**
     * 粘贴元素
     */
    pasteElement(): void;
    private isFabricObj;
    private pasteImage;
    /**
     * 裁剪元素事件
     */
    private cut;
    /**
     * 鼠标滚轮事件
     */
    private wheel;
    /**
     * 选择事件
     */
    private selectionUpdated;
    private selectionCreated;
    private removeLockObject;
}
export default EventHandler;
