import { fabric } from 'fabric';
import ParsePSDHandler from './ParsePSDHandler';
import RenderHandler from './RenderHandler';
import ZoomHandler from './ZoomHandler';
import WorkareaHandler from './WorkareaHandler';
import CommonHandler from './CommonHandler';
import ParseSketchHandler from './ParseSketchHandler';
import ParseFigmaHandler from './ParseFigmaHandler';
import TransactionHandler from './TransactionHandler';
import EventHandler from './EventHandler';
import EffectHandler from './EffectHandler';
import InteractionHandler from './InteractionHandler';
import CropImageHandler from './CropImageHandler';
import CropImageHandlerV2 from './CropImageHandlerV2';
import RenderLayerHandler from './RenderLayerHandler';
import RulerHandler from './RulerHandler';
import FilterHandler from './FilterHandler';
import LayerHandler from './LayerHandler';
import FigureHandler from './FigureHandler';
import ImageClipPathHandler from './ImageClipPathHandler';
import GroupHandler from './GroupHandler';
import AlignHandler from './AlignHandler';
import ExportHandler from './ExportHandler';
import ControlHandler from './ControlHandler';
import ShortcutHandler from './ShortcutHandler';
import { CanvasEventEmitter } from './NotifierHandler';
import GuidelineHandler from './GuidelineHandler';
import ColorHandler from './ColorHandler';
import AddHandler from './AddHandler';
import { IKeyEvent } from '../interface';
import LockHandler from './LockHandler';
interface IHandlerOption {
    canvasElParent?: HTMLDivElement;
    canvasEl?: HTMLCanvasElement;
    width?: number;
    height?: number;
    backgroundColor?: string;
    token?: string;
}
/**
 * 入口处理器，接收用户的定制内容和回调
 */
declare class Handler {
    /** @ignore */
    canvas: fabric.Canvas;
    /** @ignore */
    propertiesToInclude?: string[];
    /** @ignore */
    keyEvent?: IKeyEvent;
    interactionMode: string;
    canvasColors: string[];
    /** @ignore */
    defaultWorkareaWidth: number;
    /** @ignore */
    defaultWorkareaHeight: number;
    /** @ignore */
    parsePSDHandler: ParsePSDHandler;
    /** @ignore */
    parseSketchHandler: ParseSketchHandler;
    /** @ignore */
    parseFigmaHandler: ParseFigmaHandler;
    /** @ignore */
    renderHandler: RenderHandler;
    /** @ignore */
    zoomHandler: ZoomHandler;
    /** @ignore */
    workareaHandler: WorkareaHandler;
    /** @ignore */
    commonHandler: CommonHandler;
    /** @ignore */
    transactionHandler: TransactionHandler;
    /** @ignore */
    eventHandler: EventHandler;
    /** @ignore */
    effectHandler: EffectHandler;
    /** @ignore */
    interactionHandler: InteractionHandler;
    /** @ignore */
    cropImageHandler: CropImageHandler;
    /** @ignore */
    cropImageHandlerV2: CropImageHandlerV2;
    /** @ignore */
    rulerHandler: RulerHandler;
    /** @ignore */
    renderLayerHandler: RenderLayerHandler;
    /** @ignore */
    filterHandler: FilterHandler;
    /** @ignore */
    layerHandler: LayerHandler;
    /** @ignore */
    figureHandler: FigureHandler;
    /** @ignore */
    imageClipPathHandler: ImageClipPathHandler;
    /** @ignore */
    groupHandler: GroupHandler;
    /** @ignore */
    alignHandler: AlignHandler;
    /** @ignore */
    exportHandler: ExportHandler;
    /** @ignore */
    controlHandler: ControlHandler;
    /** @ignore */
    shortcutHandler: ShortcutHandler;
    /** @ignore */
    guidelineHandler: GuidelineHandler;
    /** @ignore */
    lockHandler: LockHandler;
    /** @ignore */
    colorHandler: ColorHandler;
    /** @ignore */
    addHandler: AddHandler;
    /** @ignore */
    event: CanvasEventEmitter;
    backgroundColor?: string;
    token?: string;
    /** @ignore */
    constructor(options: IHandlerOption);
    private initOption;
    private initHandler;
    private listenDom;
}
export default Handler;
