import { fabric } from 'fabric';
import Handler from './Handler';
/**
 * 关于画布工作区的设置
 */
declare class WorkareaHandler {
    /** @ignore */
    handler: Handler;
    workareaControlSpace: number;
    /** @ignore */
    constructor(handler: Handler);
    /**
     * 初始化workarea
     * @ignore
     * @param width 初始化的宽度
     * @param height 初始化的高度
     * @returns
     */
    init(width?: number, height?: number): fabric.Object;
    /**
     * 创建 work_mask
     * @ignore
     * @param width 创建的宽度
     * @param height 创建的高度
     * @returns
     */
    private create;
    /**
     * 设置画布工作区的颜色
     * @param type - 颜色类型，渐变或者rgba
     * @example
     * type: "rgba" - 纯色的背景类型
     * type: "gradient" - 渐变的背景类型
     * @param color - 修改的颜色，可以是纯色，也可以是fabric的渐变颜色对象
     *
     *
     * 如何将CSS的渐变属性转换为fabric的渐变对象请查看：
     * {@link ColorHandler.cssGradient2FabricGradient}
     * @returns
     */
    setBgColor(type: string, color: string | fabric.IGradientOptions): void;
    /**
     * 设置画布的尺寸
     * @param {width: 修改的宽度, height: 修改的高度}
     */
    setSize({ width, height }: {
        width: number;
        height: number;
    }): void;
    /**
     * 画布中添加一个默认的workarea
     */
    addDefaultWorkarea(): void;
    initWorkareaControl(): void;
    removeWorkareaControl(): void;
    private createWorkareaControl;
    private initWorkareaControlConfig;
    private updateControlPoints;
    private addWorkareaControlListenRemove;
    private addWorkareaControlListen;
    private getWorkareaControlPosition;
    private resetPosition;
    private resetMaxPosition;
    private showSizeBox;
    private getSizeBoxPosition;
    private showSizeText;
    private getShowText;
    private resetBg;
}
export default WorkareaHandler;
